@@ -1,4 +1,4 @@
-## Copyright (C) 2010, 2011, 2012, 2013   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -39,7 +39,7 @@
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 ## Created: May 2010
-## Version: 0.5
+## Version: 0.6
 
 ## test collection
 test ltimodels
@@ -56,6 +56,7 @@ test @lti/minreal
 test @lti/mtimes
 test @lti/norm
 test @lti/plus
+test @lti/pole
 test @lti/prescale
 test @lti/sminreal
 test @lti/subsref
@@ -106,6 +107,8 @@ test mag2db
 test margin
 test obsv
 test sigma
+test thiran
+test __dss2ss__
 
 ## identification
 test @iddata/iddata
